@@ -332,6 +332,41 @@ type EquipeInfraestruturaType = Literal[
     "Publicação AVA",
 ]
 
+type EquipeGeralType = Literal[
+    "SGA - Acadêmico",
+    "RMS (Requisições, Materiais e Serviços)",
+    "SGA - Financeiro",
+    "Recursos Humanos",
+    "Financeiro e Contábil",
+    "Saúde",
+    "SGA - Web",
+    "Administador de Banco de Dados",
+    "Escritório de Projetos",
+    "Analytics",
+    "Equipe AVA",
+    "Gerenciamento de Redes",
+    "Gerenciamento de Redes - Linux",
+    "Gerenciamento de Redes - Windows",
+    "Help-Desk - Aeroporto",
+    "Help-Desk - Ambulatório",
+    "Help-Desk - Araxá",
+    "Help-Desk - Centro",
+    "Help-Desk - HR",
+    "Help-Desk - HVU",
+    "Help-Desk - IMM",
+    "Help-Desk - MPHU",
+    "Help-Desk - NPG",
+    "Help-Desk - UPA Mirante",
+    "Help-Desk - UPA São Benedito",
+    "Help-Desk - Via Centro",
+    "Help-Desk - Vila Gávea",
+    "LIAE - Aeroporto",
+    "LIAE - Via Centro",
+    "Ouvidoria / Telefonia",
+    "Proteção de dados",
+    "Publicação AVA",
+]
+
 type ProjetoType = Literal[
     "Adequações para ONA 2022",
     "Adequações para ONA 2024",
@@ -619,5 +654,15 @@ type PrioridadeUsuarioOsType = Literal[
     "Baixa",
 ]
 
+# Type para situação do usuário
+type SituacaoUsuarioType = Literal[
+    "Bloqueado",
+    "Ativo",
+    "Bloqueado (Afastamento)",
+    "Bloqueado pelo RH (Individual)",
+    "Bloqueado por Falta de Justificativa de Ponto (Individual)",
+    "Bloqueado Licença sem Remuneração",
+]
+
 
 type TransportType = Literal["http", "stdio"]
