@@ -516,8 +516,6 @@ CATEGORIA_TO_NUMBER = {
 }
 
 # Listagem para a Combo Equipe.
-
-# Note(Arthur): Fernando, isso aqui era pra ser números? Porque tá com siglas.
 EQUIPE_TO_NUMBER = {
     "SGA - Acadêmico": "ACAD",
     "RMS (Requisições, Materiais e Serviços)": "RMS",
@@ -533,8 +531,6 @@ EQUIPE_TO_NUMBER = {
 }
 
 # Listagem para a Combo Equipe Infraestrutura.
-
-# TODO(Fernando): Atualizar os números quando forem definidos.
 EQUIPE_INFRAESTRUTURA_TO_NUMBER = {
     "Administador de Banco de Dados": "DBA",
     "Gerenciamento de Redes": "REDES",
@@ -560,6 +556,41 @@ EQUIPE_INFRAESTRUTURA_TO_NUMBER = {
     "Publicação AVA": "Pub-AVA",
 }
 
+EQUIPE_GERAL_TO_NUMBER = {
+    "SGA - Acadêmico": "ACAD",
+    "RMS (Requisições, Materiais e Serviços)": "RMS",
+    "SGA - Financeiro": "FIN",
+    "Recursos Humanos": "RH",
+    "Financeiro e Contábil": "FINCONT",
+    "Saúde": "SAUDE",
+    "SGA - Web": "SGAWEB",
+    "Administador de Banco de Dados": "DBA",
+    "Escritório de Projetos": "PROJ",
+    "Analytics": "Analytics",
+    "Equipe AVA": "AVA",
+    "Gerenciamento de Redes": "REDES",
+    "Gerenciamento de Redes - Linux": "LINUX",
+    "Gerenciamento de Redes - Windows": "WINDOWS",
+    "Help-Desk - Aeroporto": "Help Aero",
+    "Help-Desk - Ambulatório": "Help Amb",
+    "Help-Desk - Araxá": "Help Ara",
+    "Help-Desk - Centro": "Help Cen",
+    "Help-Desk - HR": "Help HR",
+    "Help-Desk - HVU": "Help HVU",
+    "Help-Desk - IMM": "Help IMM",
+    "Help-Desk - MPHU": "Help MPHU",
+    "Help-Desk - NPG": "Help NPG",
+    "Help-Desk - UPA Mirante": "Help UPA_M",
+    "Help-Desk - UPA São Benedito": "Help UPASB",
+    "Help-Desk - Via Centro": "Help Mar",
+    "Help-Desk - Vila Gávea": "Help Vila",
+    "LIAE - Aeroporto": "LIAE Aero",
+    "LIAE - Via Centro": "LIAE Mar",
+    "Ouvidoria / Telefonia": "OUVIDORIA",
+    "Proteção de dados": "DPO",
+    "Publicação AVA": "Pub-AVA",
+}
+
 # Listagem para a Combo Projeto.
 PROJETO_TO_NUMBER = {
     "Adequações para ONA 2022": (107),
@@ -800,6 +831,17 @@ PRIORIDADE_USUARIO_OS_TO_NUMBER = {
 }
 
 
+# Constante para situação do usuário
+SITUACAO_USUARIO_TO_NUMBER = {
+    "Bloqueado": 0,
+    "Ativo": 1,
+    "Bloqueado (Afastamento)": 2,
+    "Bloqueado pelo RH (Individual)": 3,
+    "Bloqueado por Falta de Justificativa de Ponto (Individual)": 4,
+    "Bloqueado Licença sem Remuneração": 5,
+}
+
+
 def _safe_langfuse_prompt(key: str, default: str = "") -> str:
     try:
         # langfuse may be None if not installed or not initialized
