@@ -3,12 +3,27 @@ from textwrap import dedent
 
 def docs() -> str:
     return dedent("""\
+            Edita as informações de um atendimento avulso infraestrutura existente no sistema SIGA.
+
+            **INSTRUÇÃO PARA O AGENTE IA:**
+            ANTES de executar esta função de edição:
+            1. SEMPRE chame primeiro `buscar_informacoes_atendimento_avulso(codigo_atendimento, codigo_analista)`
+            2. MOSTRE ao usuário os dados atuais vs. dados que serão alterados em formato claro e comparativo
+            3. PEÇA confirmação explícita do usuário: "Confirma as alterações? (sim/não)"
+            4. SÓ EXECUTE esta função se o usuário confirmar explicitamente
+            5. Se o usuário não confirmar, cancele a operação e informe que foi cancelada
+                  
             Esta função atualiza um registro de atendimento avulso independente de qualquer Ordem de Serviço, incluindo informações como datas, descrição, tipo, origem, categoria, equipe, projeto e plaqueta.
             Realiza validação de todos os campos obrigatórios e conversão automática de datas.
+                  
+            **Funcionalidade de busca automática:**
+            Se o atendimento não for encontrado nesta função (atendimentos avulso infraestrutura), a mensagem de erro orientará a buscar nas funções editar_atendimentos_os ou editar_atendimento_avulso_sistemas, permitindo busca automática entre os tipos de atendimento.
 
             **Endpoint utilizado:** atualizarAtendimentoAvulsoSigaIA
 
             **Estrutura do XML retornado:**
+                  
+            **Sucesso:**
             ```xml
             <atendimentos_avulsos_infra codigo_atendimento="123" dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00"
                                         matSolicitante="123456" tipo="14" descricao="Descrição"
@@ -20,7 +35,7 @@ def docs() -> str:
             </atendimentos_avulsos_infra>
             ```
 
-            **Em caso de erro de validação:**
+            **Em caso de erro de validação (campo inválido):**
             ```xml
             <erro_validacao sistema="SIGA" funcao="editar_atendimento_avulso_infraestrutura">
                 <erro sistema="SIGA">
@@ -31,6 +46,27 @@ def docs() -> str:
                     <tipos_validos>['Atividade Interna', 'Implementação', 'Incidente', 'Manutenção Corretiva', 'Manutenção de Banco', 'Manutenção Preventiva', 'Monitoramento',	'Requisição', 'Suporte', 'Treinamento']</tipos_validos>
                 </erro>
             </erro_validacao>
+            ```                  
+            
+            **Em caso de erro (atendimento não encontrado):**
+            ```xml
+            <atendimentos_avulsos_infra codigo_atendimento="99999" dataIni="2024-01-15 09:00:00" dataFim="2024-01-15 17:00:00" matSolicitante="123456" tipo="14" descricao="Teste"
+                            origem="1" equipe="Help Aero" analista="789" projeto="61" categoria="27" plaqueta="">
+                <atendimento_avulso_infra sistema="SIGA">
+                    <status>erro</status>
+                    <mensagem>Atendimento não encontrado em Avulso Infraestrutura. Tente buscar nas funções editar_atendimentos_os ou editar_atendimento_avulso_sistemas.</mensagem>
+                </atendimento_avulso_infra>
+            </atendimentos_avulsos_infra>
+            ```
+                  
+            **Em caso de outros erros:**
+            ```xml
+            <atendimentos_avulsos_infra codigo_atendimento="123" dataIni="2024-01-15 09:00:00"  dataFim="2024-01-15 17:00:00" matSolicitante="123456" tipo="14" descricao="Descrição" origem="1" equipe="Help Aero" analista="789" projeto="61" categoria="27" plaqueta="222222">
+                <atendimento_avulso_infra sistema="SIGA">
+                    <status>erro</status>
+                    <mensagem>Erro ao gravar o atendimento avulso. Tente novamente.</mensagem>
+                </atendimento_avulso_infra>
+            </atendimentos_avulsos_infra>
             ```
 
             Args:
@@ -54,9 +90,9 @@ def docs() -> str:
                     - "Suporte" (código 14) - padrão
                     - "Treinamento" (código 18)
                 origem (Literal): Canal/origem do atendimento avulso, deve ser um dos valores válidos:
-                    - "E-mail" (código 1)
+                    - "E-mail" (código 1) - padrão
                     - "Pessoalmente" (código 2)
-                    - "Teams" (código 3) - padrão
+                    - "Teams" (código 3)
                     - "Telefone" (código 4)
                     - "WhatsApp" (código 5)
                     - "Plantão" (código 7)
@@ -343,10 +379,12 @@ def docs() -> str:
 
             Returns:
                 str: XML formatado contendo:
-                    - Em caso de sucesso: confirmação da edição com status "sucesso"
-                    - Em caso de erro de validação: detalhes do erro com valores válidos para o campo inválido
-                    - Em caso de erro de API: mensagem de erro específica
+                    - Em caso de sucesso: confirmação da edição com status "sucesso" 
+                    - Em caso de atendimento não encontrado: status "erro" com orientação para buscar em outras funções 
+                    - Em caso de outros erros de validação: detalhes do erro com valores válidos para o campo inválido 
+                    - Em caso de outros erros de API: status "erro" com mensagem explicativa 
                     - Em caso de erro interno: mensagem de erro genérica
+                  
                 O XML sempre inclui os parâmetros enviados como atributos do elemento raiz.
 
             Raises:
@@ -362,6 +400,7 @@ def docs() -> str:
                 ...     descricao_atendimento="Suporte ao sistema AVA",
                 ...     codigo_analista=789
                 ... )
+                  
                 >>> # Editar atendimento com projeto específico
                 >>> xml = await editar_atendimento_avulso_infraestrutura(
                 ...     codigo_atendimento=456,
@@ -377,6 +416,17 @@ def docs() -> str:
                 ...     projeto="Operação Help Desk",
                 ...     plaqueta="222222"
                 ... )
+                  
+                >>> # Exemplo quando não encontra (orienta busca automática)
+                >>> xml = await editar_atendimento_avulso_infraestrutura(
+                ...     codigo_atendimento=99999,
+                ...     data_inicio="2024-01-15 09:00:00",
+                ...     data_fim="2024-01-15 17:00:00",
+                ...     matricula_solicitante="123456",
+                ...     descricao_atendimento="Teste",
+                ...     codigo_analista=789
+                ... )
+                  
                 >>> # Exemplo com tipo inválido (retorna erro)
                 >>> xml = await editar_atendimento_avulso_infraestrutura(
                 ...     codigo_atendimento=789,
@@ -389,7 +439,9 @@ def docs() -> str:
                 ... )
 
             Notes:
-                - Esta função é específica para ÁREA INFRAESTRUTURA (área=2)
+                - **ATENÇÃO**: Esta operação modifica permanentemente os dados do atendimento
+                - **DIFERENCIAÇÃO DE TIPOS**: Esta função é específica para atendimentos avulso infraestrutura. Para outros tipos, use as funções específicas
+                - Para busca automática: Se não encontrar nesta função, use editar_atendimentos_os ou editar_atendimento_avulso_sistemas com os mesmos parâmetros
                 - A função realiza validação case-insensitive de todos os campos (tipo, origem, categoria, equipe, projeto)
                 - As datas são automaticamente convertidas usando converter_data_siga com manter_horas=True
                 - Utiliza as constantes: TIPO_TO_NUMBER_ATENDIMENTO_AVULSO_INFRAESTRUTURA, ORIGEM_TO_NUMBER, CATEGORIA_TO_NUMBER, EQUIPE_INFRAESTRUTURA_TO_NUMBER, PROJETO_TO_NUMBER para mapear valores para códigos numéricos
