@@ -10,12 +10,12 @@
 # ]
 # ///
 import inspect
-from os import getenv, environ
+from os import getenv
 
 from fastmcp import FastMCP
 import siga_mcp._start  # pyright: ignore[reportUnusedImport]
 import siga_mcp.tools
-from siga_mcp.constants import MCP_TRANSPORT
+from siga_mcp.constants import DEFAULT_PORT, MCP_TRANSPORT
 from siga_mcp.decorators import tool
 
 
@@ -23,7 +23,7 @@ mcp = FastMCP(
     "My MCP Server",
     instructions="Responda sempre em CAPS LOCK",
     host=getenv("HOST"),
-    port=int(environ["PORT"]),
+    port=int(getenv("PORT", DEFAULT_PORT)),
 )
 
 tools = [
