@@ -1,5 +1,4 @@
 import calendar
-from pathlib import Path
 import re
 from datetime import datetime, timedelta
 from os import getenv
@@ -14,6 +13,7 @@ from siga_mcp.constants import (
     DIAS_SEMANA_PT,
     MESES_PT,
     NUMEROS_EXTENSO,
+    PACKAGE_NAME,
     PERIODOS_DIA,
     TEAMS_CLIENT_ID,
     TEAMS_CLIENT_SECRET,
@@ -1280,18 +1280,55 @@ def send_message_to_user(user_id: str, message_text: str):
         )
 
 
-def get_version() -> str:
-    # find pyproject.toml in parent directories and read version from it
-    pyproject_dir = Path(__file__).parent.parent
-    pyproject_path = pyproject_dir / "pyproject.toml"
-    if pyproject_path.exists():
-        with open(pyproject_path, "r", encoding="utf-8") as f:
-            for line in f:
-                if line.startswith("version"):
-                    return line.split("=")[1].strip().strip('"')
+def get_package_version() -> str:
+    """
+    Obtém a versão atual do pacote a partir do PyPI, com fallback para o pyproject.toml local.
 
+    Estratégia:
+    1) Tenta buscar a versão no endpoint JSON do PyPI: https://pypi.org/pypi/siga-mcp/json
+       - Extrai o campo info.version
+    2) Se falhar (sem rede/timeout/erro), tenta ler a versão do pyproject.toml local.
+    3) Se nada funcionar, retorna "<not found>".
+
+    Returns:
+        str: Versão do pacote se encontrada, caso contrário "<not found>".
+    """
+
+    pypi_url = f"https://pypi.org/pypi/{PACKAGE_NAME}/json"
+
+    # 1) Tenta via PyPI
+    try:
+        resp = requests.get(pypi_url, timeout=5)
+        if resp.ok:
+            try:
+                raw = resp.json()
+            except Exception:
+                # Fallback parsing caso json() falhe
+                raw = ujson.loads(resp.text)
+
+            data: dict[str, Any] = (
+                cast(dict[str, Any], raw) if isinstance(raw, dict) else {}
+            )
+            info = data.get("info")
+            if isinstance(info, dict):
+                info = cast(dict[str, Any], info)
+                version = info.get("version")
+                if isinstance(version, str) and version:
+                    return version
+    except Exception:
+        # Silenciar e seguir para fallback local
+        pass
+
+    # 3) Não encontrado
     return "<not found>"
 
 
+def montar_string(items: dict[str, str | int | bool], separator: str = "-") -> str:
+    print(f"        {separator} ", end="")
+    return f"\n        {separator} ".join(
+        [f'"{key}" (Código {value})' for key, value in items.items()]
+    )
+
+
 if __name__ == "__main__":
-    print(get_version())
+    print(montar_string({"teste": 123, "teste2": 456}))
