@@ -2,7 +2,7 @@ import asyncio
 
 # from siga_mcp.tools import inserir_os_infraestrutura
 # from siga_mcp.dynamic_constants import obter_usuarios_responsavel
-from siga_mcp.tools import listar_usuarios_equipe_por_gerente
+from siga_mcp.tools import listar_horas_trabalhadas
 
 from dotenv import load_dotenv
 
@@ -74,7 +74,7 @@ if __name__ == "__main__":
     print(resultado) """
 
 
-async def main() -> str:
+""" async def main() -> str:
     return await listar_usuarios_equipe_por_gerente(
         **{
             "matricula_gerente": "8372",
@@ -84,6 +84,21 @@ async def main() -> str:
     )
 
 
+if __name__ == "__main__":
+    resultado = asyncio.run(main())
+    print(resultado) """
+
+
+async def main() -> str:
+    return await listar_horas_trabalhadas(
+        **{
+            "matricula": ["24142", "14897"],
+            "data_inicio": "13/10/2025",
+            "data_fim": "17/10/2025",
+        }
+    )
+
+
 if __name__ == "__main__":
     resultado = asyncio.run(main())
     print(resultado)
